%define upstream_name    Parser-MGC
%define upstream_version 0.23

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Build simple recursive-descent parsers
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Parser/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Feature::Compat::Try)
BuildRequires: perl(File::Temp)
BuildRequires: perl(Module::Build) >= 0.400.400
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Test2::V0)
BuildArch:  noarch

%description
This base class provides a low-level framework for building
recursive-descent parsers that consume a given input string from left to
right, returning a parse structure. It takes its name from the 'm//gc'
regexps used to implement the token parsing behaviour.

It provides a number of token-parsing methods, which each extract a
grammatical token from the string. It also provides wrapping methods that
can be used to build up a possibly-recursive grammar structure, by applying
a structure around other parts of parsing code. Each method, both token and
structural, atomically either consumes a prefix of the string and returns
its result, or fails and consumes nothing. This makes it simple to
implement grammars that require backtracking.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Build.PL --installdirs=vendor

./Build CFLAGS="%{optflags}"

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README examples
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Tue Jul 01 2025 umeabot <umeabot> 0.230.0-2.mga10
+ Revision: 2234688
- Mageia 10 Mass Rebuild

* Fri Jan 24 2025 tv <tv> 0.230.0-1.mga10
+ Revision: 2141845
- update to 0.23

* Sat Oct 19 2024 daviddavid <daviddavid> 0.220.0-3.mga10
+ Revision: 2108441
- rebuild again with fixed perl generator in rpm-mageia-setup-2.80-7.mga10

* Tue Oct 15 2024 daviddavid <daviddavid> 0.220.0-2.mga10
+ Revision: 2107059
- rebuild with fixed perl attr in rpm-mageia-setup-2.80-5.mga10

* Tue Oct 15 2024 tv <tv> 0.220.0-1.mga10
+ Revision: 2106953
- update to 0.22

* Mon Mar 21 2022 umeabot <umeabot> 0.210.0-2.mga9
+ Revision: 1816381
- Mageia 9 Mass Rebuild

* Thu Feb 24 2022 tv <tv> 0.210.0-1.mga9
+ Revision: 1784053
- update to 0.21

* Wed Feb 16 2022 tv <tv> 0.200.0-1.mga9
+ Revision: 1777622
- update to 0.20

* Wed Apr 28 2021 tv <tv> 0.190.0-1.mga9
+ Revision: 1720249
- update to 0.19

* Mon Mar 29 2021 tv <tv> 0.180.0-1.mga9
+ Revision: 1711680
- update to 0.18

* Wed Feb 12 2020 umeabot <umeabot> 0.160.0-4.mga8
+ Revision: 1505911
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0.160.0-3.mga7
+ Revision: 1285567
- Mageia 7 Mass Rebuild

* Tue Oct 03 2017 tv <tv> 0.160.0-2.mga7
+ Revision: 1166136
- rebuild with fixed rpm for missing autodeps

* Sat Sep 23 2017 sander85 <sander85> 0.160.0-1.mga7
+ Revision: 1157912
- update to 0.16

* Sun Jun 19 2016 pterjan <pterjan> 0.150.0-2.mga6
+ Revision: 1031776
- Rebuild for perl 5.22.2

* Thu Dec 17 2015 shlomif <shlomif> 0.150.0-1.mga6
+ Revision: 911369
- New version 0.15

* Wed Sep 02 2015 shlomif <shlomif> 0.140.0-1.mga6
+ Revision: 872285
- New version 0.14

* Sun Jul 05 2015 sander85 <sander85> 0.130.0-1.mga6
+ Revision: 851526
- update to 0.13

* Sun Oct 19 2014 umeabot <umeabot> 0.120.0-5.mga5
+ Revision: 788761
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.120.0-4.mga5
+ Revision: 751138
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.120.0-3.mga5
+ Revision: 685905
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.120.0-2.mga4
+ Revision: 533982
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 sander85 <sander85> 0.120.0-1.mga4
+ Revision: 475950
- update to 0.12

* Sun Jan 13 2013 umeabot <umeabot> 0.110.0-2.mga3
+ Revision: 371562
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 shlomif <shlomif> 0.110.0-1.mga3
+ Revision: 324129
- imported package perl-Parser-MGC


* Sat Dec 01 2012 cpan2dist 0.11-1mga
- initial mageia release, generated with cpan2dist
